CustomPopupButton class

Inheritance

Constructors

CustomPopupButton({Key? key, required Widget icon, required List<CustomPopupMenuElement> items, Widget? closeIcon, Color? backgroundColor, CustomPopupPosition? position, double? width, double? buttonRadius, double? borderRadius, double? spacing, double? buttonPadding, Alignment animationAlignment = Alignment.topCenter})
const

Properties

animationAlignment Alignment
From where the scale animation starts.
final
backgroundColor Color?
The background color of the popup
final
borderRadius double?
The border radius of the popup
final
buttonPadding double?
The padding of the button
final
buttonRadius double?
The border radius of the popup
final
closeIcon Widget?
The icon that closes the popup
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
The icon that opens the popup
final
items List<CustomPopupMenuElement>
The items inside of the popup
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
position CustomPopupPosition?
The position of the popup
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double?
The spacing between the elements
final
width double?
The width of the popup
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CustomPopupButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited