backgroundColor property
The background color of the popup
If not set it will default to the surface color of the theme
Implementation
final Color? backgroundColor;
The background color of the popup
If not set it will default to the surface color of the theme
final Color? backgroundColor;