borderRadius property
The border radius of the popup
If not set it will default to the border radius of the theme
Implementation
final double? borderRadius;
The border radius of the popup
If not set it will default to the border radius of the theme
final double? borderRadius;