buttonPadding property
The padding of the button
If not set it will default to the padding of the theme
Implementation
final double? buttonPadding;
The padding of the button
If not set it will default to the padding of the theme
final double? buttonPadding;