buttonRadius property
The border radius of the popup
If not set it will default to the border radius of the theme
Implementation
final double? buttonRadius;
The border radius of the popup
If not set it will default to the border radius of the theme
final double? buttonRadius;