spacing property
The spacing between the elements
If not set it will default to the spacing of the theme
Implementation
final double? spacing;
The spacing between the elements
If not set it will default to the spacing of the theme
final double? spacing;