CustomPopupButtonTheme class

Inheritance

Constructors

CustomPopupButtonTheme({Color? backgroundColor, Color? foregroundColor, double padding = CustomPopupThemeDefaults.defaultSmallSpacing, double spacing = 2, double borderRadius = CustomPopupThemeDefaults.defaultSmallBorderRadius})
const

Properties

backgroundColor Color?
Background color of the button. If null, the default color is used.
final
borderRadius double
Border radius of the button. The default border radius is CustomPopupThemeDefaults.defaultSmallBorderRadius.
final
foregroundColor Color?
Foreground color of the button. If null, the default color is used.
final
hashCode int
The hash code for this object.
no setterinherited
padding double
Padding of the button. The default padding is CustomPopupThemeDefaults.defaultSmallSpacing.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
Spacing between the button and its child. The default spacing is 2.
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? backgroundColor, Color? foregroundColor, double? padding, double? spacing, double? borderRadius}) CustomPopupButtonTheme
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<CustomPopupButtonTheme>? other, double t) CustomPopupButtonTheme
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited