CustomPopupMenuItem class

Inheritance

Constructors

CustomPopupMenuItem({Key? key, required String label, required Widget icon, required VoidCallback onTap, double height = 35, double? spacing, Color? foregroundColor, Color? backgroundColor})
A button in the popup
const

Properties

backgroundColor Color?
The background color of the button
final
foregroundColor Color?
The foreground color of the button
final
hashCode int
The hash code for this object.
no setterinherited
height double
The height of the button, default is 35
final
icon Widget
The icon of the button
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
The label of the button
final
onTap VoidCallback
The function that is called when the button is pressed
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double?
The space between the icon and the label
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
calculateWidgetHeight(BuildContext context) double
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited