buttonPadding property
The padding of the button to open the popup
Defaults to CustomPopupThemeDefaults.defaultSmallSpacing.
Implementation
final double buttonPadding;
The padding of the button to open the popup
Defaults to CustomPopupThemeDefaults.defaultSmallSpacing.
final double buttonPadding;