buttonTheme property
The theme of the button inside the popup menu.
Defaults to CustomPopupButtonTheme.
Implementation
final CustomPopupButtonTheme buttonTheme;
The theme of the button inside the popup menu.
Defaults to CustomPopupButtonTheme.
final CustomPopupButtonTheme buttonTheme;