itemSpacing property
The spacing between the button in the popup menu.
Defaults to CustomPopupThemeDefaults.defaultSmallSpacing.
Implementation
final double itemSpacing;
The spacing between the button in the popup menu.
Defaults to CustomPopupThemeDefaults.defaultSmallSpacing.
final double itemSpacing;