spacing property
The spacing between default elements in the popup menu.
Defaults to CustomPopupThemeDefaults.defaultSpacing.
Implementation
final double spacing;
The spacing between default elements in the popup menu.
Defaults to CustomPopupThemeDefaults.defaultSpacing.
final double spacing;