CustomPopupTheme class
- Inheritance
-
- Object
- ThemeExtension<
CustomPopupTheme> - CustomPopupTheme
Constructors
- CustomPopupTheme({Color? backgroundColor, CustomPopupPosition position = CustomPopupPosition.relative, CustomPopupButtonTheme buttonTheme = const CustomPopupButtonTheme(), double width = CustomPopupThemeDefaults.defaultWidth, double buttonRadius = CustomPopupThemeDefaults.defaultSmallBorderRadius, double borderRadius = CustomPopupThemeDefaults.defaultBorderRadius, double itemSpacing = CustomPopupThemeDefaults.defaultSmallSpacing, double spacing = CustomPopupThemeDefaults.defaultSpacing, double buttonPadding = CustomPopupThemeDefaults.defaultSmallSpacing})
-
const
- CustomPopupTheme.fallback()
-
const
Properties
- backgroundColor → Color?
-
Background color of the popup menu.
final
- borderRadius → double
-
The radius of the corners of the popup menu's large elements.
final
-
The padding of the button to open the popup
final
-
The radius of the corners of the popup menu's button.
final
-
The theme of the button inside the popup menu.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemSpacing → double
-
The spacing between the button in the popup menu.
final
- position → CustomPopupPosition
-
The position of the popup menu.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
The spacing between default elements in the popup menu.
final
- type → Object
-
The extension's type.
no setterinherited
- width → double
-
The width of the popup menu.
final
Methods
-
copyWith(
{Color? backgroundColor, CustomPopupPosition? position, CustomPopupButtonTheme? buttonTheme, double? width, double? buttonRadius, double? borderRadius, double? itemSpacing, double? spacing, double? buttonPadding}) → CustomPopupTheme -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< CustomPopupTheme> ? other, double t) → CustomPopupTheme -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited